Class: Google::Apis::MemcacheV1::GoogleCloudSaasacceleratorManagementProvidersV1Instance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/memcache_v1/classes.rb,
lib/google/apis/memcache_v1/representations.rb,
lib/google/apis/memcache_v1/representations.rb

Overview

Instance represents the interface for SLM services to actuate the state of control plane resources. Example Instance in JSON, where consumer-project- number=123456, producer-project-id=cloud-sql: json Instance: ` "name": " projects/123456/locations/us-east1/instances/prod-instance", "create_time": ` " seconds": 1526406431, `, "labels": ` "env": "prod", "foo": "bar" `, "state": READY, "software_versions": ` "software_update": "cloud-sql-09-28-2018", `, " maintenance_policy_names": ` "UpdatePolicy": "projects/123456/locations/us- east1/maintenancePolicies/prod-update-policy", ` "tenant_project_id": "cloud- sql-test-tenant", "producer_metadata": ` "cloud-sql-tier": "basic", "cloud-sql- instance-size": "1G", `, "provisioned_resources": [ ` "resource-type": " compute-instance", "resource-url": "https://www.googleapis.com/compute/v1/ projects/cloud-sql/zones/us-east1-b/instances/vm-1", ` ], " maintenance_schedules": ` "csa_rollout": ` "start_time": ` "seconds": 1526406431, `, "end_time": ` "seconds": 1535406431, `, `, "ncsa_rollout": ` " start_time": ` "seconds": 1526406431, `, "end_time": ` "seconds": 1535406431, ` , ` `, "consumer_defined_name": "my-sql-instance1", ` LINT.IfChange

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSaasacceleratorManagementProvidersV1Instance

Returns a new instance of GoogleCloudSaasacceleratorManagementProvidersV1Instance.



551
552
553
# File 'lib/google/apis/memcache_v1/classes.rb', line 551

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#consumer_defined_nameString

consumer_defined_name is the name of the instance set by the service consumers. Generally this is different from the name field which reperesents the system-assigned id of the instance which the service consumers do not recognize. This is a required field for tenants onboarding to Maintenance Window notifications (go/slm-rollout-maintenance-policies#prerequisites). Corresponds to the JSON property consumerDefinedName

Returns:

  • (String)


429
430
431
# File 'lib/google/apis/memcache_v1/classes.rb', line 429

def consumer_defined_name
  @consumer_defined_name
end

#consumer_project_numberString

Optional. The consumer_project_number associated with this Apigee instance. This field is added specifically to support Apigee integration with SLM Rollout and UMM. It represents the numerical project ID of the GCP project that consumes this Apigee instance. It is used for SLM rollout notifications and UMM integration, enabling proper mapping to customer projects and log delivery for Apigee instances. This field complements consumer_project_id and may be used for specific Apigee scenarios where the numerical ID is required. Corresponds to the JSON property consumerProjectNumber

Returns:

  • (String)


440
441
442
# File 'lib/google/apis/memcache_v1/classes.rb', line 440

def consumer_project_number
  @consumer_project_number
end

#create_timeString

Output only. Timestamp when the resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


445
446
447
# File 'lib/google/apis/memcache_v1/classes.rb', line 445

def create_time
  @create_time
end

#instance_typeString

Optional. The instance_type of this instance of format: projects/ project_number/locations/location_id/instanceTypes/instance_type_id. Instance Type represents a high-level tier or SKU of the service that this instance belong to. When enabled(eg: Maintenance Rollout), Rollout uses ' instance_type' along with 'software_versions' to determine whether instance needs an update or not. Corresponds to the JSON property instanceType

Returns:

  • (String)


455
456
457
# File 'lib/google/apis/memcache_v1/classes.rb', line 455

def instance_type
  @instance_type
end

#labelsHash<String,String>

Optional. Resource labels to represent user provided metadata. Each label is a key-value pair, where both the key and the value are arbitrary strings provided by the user. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


462
463
464
# File 'lib/google/apis/memcache_v1/classes.rb', line 462

def labels
  @labels
end

#maintenance_policy_namesHash<String,String>

Optional. The MaintenancePolicies that have been attached to the instance. The key must be of the type name of the oneof policy name defined in MaintenancePolicy, and the referenced policy must define the same policy type. For details, please refer to go/mr-user-guide. Should not be set if maintenance_settings.maintenance_policies is set. Corresponds to the JSON property maintenancePolicyNames

Returns:

  • (Hash<String,String>)


471
472
473
# File 'lib/google/apis/memcache_v1/classes.rb', line 471

def maintenance_policy_names
  @maintenance_policy_names
end

#maintenance_schedulesHash<String,Google::Apis::MemcacheV1::GoogleCloudSaasacceleratorManagementProvidersV1MaintenanceSchedule>

The MaintenanceSchedule contains the scheduling information of published maintenance schedule with same key as software_versions. Corresponds to the JSON property maintenanceSchedules



477
478
479
# File 'lib/google/apis/memcache_v1/classes.rb', line 477

def maintenance_schedules
  @maintenance_schedules
end

#maintenance_settingsGoogle::Apis::MemcacheV1::GoogleCloudSaasacceleratorManagementProvidersV1MaintenanceSettings

Maintenance settings associated with instance. Allows service producers and end users to assign settings that controls maintenance on this instance. Corresponds to the JSON property maintenanceSettings



483
484
485
# File 'lib/google/apis/memcache_v1/classes.rb', line 483

def maintenance_settings
  @maintenance_settings
end

#nameString

Unique name of the resource. It uses the form: projects/project_number/ locations/location_id/instances/instance_id`Note: This name is passed, stored and logged across the rollout system. So use of consumer project_id or any other consumer PII in the name is strongly discouraged for wipeout (go/ wipeout) compliance. See go/elysium/project_ids#storage-guidance for more details. Corresponds to the JSON propertyname`

Returns:

  • (String)


493
494
495
# File 'lib/google/apis/memcache_v1/classes.rb', line 493

def name
  @name
end

#notification_parametersHash<String,Google::Apis::MemcacheV1::GoogleCloudSaasacceleratorManagementProvidersV1NotificationParameter>

Optional. notification_parameter are information that service producers may like to include that is not relevant to Rollout. This parameter will only be passed to Gamma and Cloud Logging for notification/logging purpose. Corresponds to the JSON property notificationParameters



500
501
502
# File 'lib/google/apis/memcache_v1/classes.rb', line 500

def notification_parameters
  @notification_parameters
end

#producer_metadataHash<String,String>

Output only. Custom string attributes used primarily to expose producer- specific information in monitoring dashboards. See go/get-instance-metadata. Corresponds to the JSON property producerMetadata

Returns:

  • (Hash<String,String>)


506
507
508
# File 'lib/google/apis/memcache_v1/classes.rb', line 506

def 
  @producer_metadata
end

#provisioned_resourcesArray<Google::Apis::MemcacheV1::GoogleCloudSaasacceleratorManagementProvidersV1ProvisionedResource>

Output only. The list of data plane resources provisioned for this instance, e. g. compute VMs. See go/get-instance-metadata. Corresponds to the JSON property provisionedResources



512
513
514
# File 'lib/google/apis/memcache_v1/classes.rb', line 512

def provisioned_resources
  @provisioned_resources
end

#slm_instance_templateString

Link to the SLM instance template. Only populated when updating SLM instances via SSA's Actuation service adaptor. Service producers with custom control plane (e.g. Cloud SQL) doesn't need to populate this field. Instead they should use software_versions. Corresponds to the JSON property slmInstanceTemplate

Returns:

  • (String)


520
521
522
# File 'lib/google/apis/memcache_v1/classes.rb', line 520

def slm_instance_template
  @slm_instance_template
end

#slo_metadataGoogle::Apis::MemcacheV1::GoogleCloudSaasacceleratorManagementProvidersV1SloMetadata

SloMetadata contains resources required for proper SLO classification of the instance. Corresponds to the JSON property sloMetadata



526
527
528
# File 'lib/google/apis/memcache_v1/classes.rb', line 526

def 
  @slo_metadata
end

#software_versionsHash<String,String>

Software versions that are used to deploy this instance. This can be mutated by rollout services. Corresponds to the JSON property softwareVersions

Returns:

  • (Hash<String,String>)


532
533
534
# File 'lib/google/apis/memcache_v1/classes.rb', line 532

def software_versions
  @software_versions
end

#stateString

Output only. Current lifecycle state of the resource (e.g. if it's being created or ready to use). Corresponds to the JSON property state

Returns:

  • (String)


538
539
540
# File 'lib/google/apis/memcache_v1/classes.rb', line 538

def state
  @state
end

#tenant_project_idString

Output only. ID of the associated GCP tenant project. See go/get-instance- metadata. Corresponds to the JSON property tenantProjectId

Returns:

  • (String)


544
545
546
# File 'lib/google/apis/memcache_v1/classes.rb', line 544

def tenant_project_id
  @tenant_project_id
end

#update_timeString

Output only. Timestamp when the resource was last modified. Corresponds to the JSON property updateTime

Returns:

  • (String)


549
550
551
# File 'lib/google/apis/memcache_v1/classes.rb', line 549

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
# File 'lib/google/apis/memcache_v1/classes.rb', line 556

def update!(**args)
  @consumer_defined_name = args[:consumer_defined_name] if args.key?(:consumer_defined_name)
  @consumer_project_number = args[:consumer_project_number] if args.key?(:consumer_project_number)
  @create_time = args[:create_time] if args.key?(:create_time)
  @instance_type = args[:instance_type] if args.key?(:instance_type)
  @labels = args[:labels] if args.key?(:labels)
  @maintenance_policy_names = args[:maintenance_policy_names] if args.key?(:maintenance_policy_names)
  @maintenance_schedules = args[:maintenance_schedules] if args.key?(:maintenance_schedules)
  @maintenance_settings = args[:maintenance_settings] if args.key?(:maintenance_settings)
  @name = args[:name] if args.key?(:name)
  @notification_parameters = args[:notification_parameters] if args.key?(:notification_parameters)
  @producer_metadata = args[:producer_metadata] if args.key?(:producer_metadata)
  @provisioned_resources = args[:provisioned_resources] if args.key?(:provisioned_resources)
  @slm_instance_template = args[:slm_instance_template] if args.key?(:slm_instance_template)
  @slo_metadata = args[:slo_metadata] if args.key?(:slo_metadata)
  @software_versions = args[:software_versions] if args.key?(:software_versions)
  @state = args[:state] if args.key?(:state)
  @tenant_project_id = args[:tenant_project_id] if args.key?(:tenant_project_id)
  @update_time = args[:update_time] if args.key?(:update_time)
end