Class: Google::Apis::MemcacheV1::MaintenanceSchedule
- Inherits:
-
Object
- Object
- Google::Apis::MemcacheV1::MaintenanceSchedule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/memcache_v1/classes.rb,
lib/google/apis/memcache_v1/representations.rb,
lib/google/apis/memcache_v1/representations.rb
Overview
Upcoming maintenance schedule.
Instance Attribute Summary collapse
-
#end_time ⇒ String
Output only.
-
#schedule_deadline_time ⇒ String
Output only.
-
#start_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MaintenanceSchedule
constructor
A new instance of MaintenanceSchedule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MaintenanceSchedule
Returns a new instance of MaintenanceSchedule.
1281 1282 1283 |
# File 'lib/google/apis/memcache_v1/classes.rb', line 1281 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time ⇒ String
Output only. The end time of any upcoming scheduled maintenance for this
instance.
Corresponds to the JSON property endTime
1267 1268 1269 |
# File 'lib/google/apis/memcache_v1/classes.rb', line 1267 def end_time @end_time end |
#schedule_deadline_time ⇒ String
Output only. The deadline that the maintenance schedule start time can not go
beyond, including reschedule.
Corresponds to the JSON property scheduleDeadlineTime
1273 1274 1275 |
# File 'lib/google/apis/memcache_v1/classes.rb', line 1273 def schedule_deadline_time @schedule_deadline_time end |
#start_time ⇒ String
Output only. The start time of any upcoming scheduled maintenance for this
instance.
Corresponds to the JSON property startTime
1279 1280 1281 |
# File 'lib/google/apis/memcache_v1/classes.rb', line 1279 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1286 1287 1288 1289 1290 |
# File 'lib/google/apis/memcache_v1/classes.rb', line 1286 def update!(**args) @end_time = args[:end_time] if args.key?(:end_time) @schedule_deadline_time = args[:schedule_deadline_time] if args.key?(:schedule_deadline_time) @start_time = args[:start_time] if args.key?(:start_time) end |