Class: Google::Apis::MemcacheV1::MemcacheParameters
- Inherits:
-
Object
- Object
- Google::Apis::MemcacheV1::MemcacheParameters
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/memcache_v1/classes.rb,
lib/google/apis/memcache_v1/representations.rb,
lib/google/apis/memcache_v1/representations.rb
Instance Attribute Summary collapse
-
#id ⇒ String
Output only.
-
#params ⇒ Hash<String,String>
User defined set of parameters to use in the memcached process.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MemcacheParameters
constructor
A new instance of MemcacheParameters.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MemcacheParameters
Returns a new instance of MemcacheParameters.
1357 1358 1359 |
# File 'lib/google/apis/memcache_v1/classes.rb', line 1357 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Output only. The unique ID associated with this set of parameters. Users can
use this id to determine if the parameters associated with the instance differ
from the parameters associated with the nodes. A discrepancy between parameter
ids can inform users that they may need to take action to apply parameters on
nodes.
Corresponds to the JSON property id
1350 1351 1352 |
# File 'lib/google/apis/memcache_v1/classes.rb', line 1350 def id @id end |
#params ⇒ Hash<String,String>
User defined set of parameters to use in the memcached process.
Corresponds to the JSON property params
1355 1356 1357 |
# File 'lib/google/apis/memcache_v1/classes.rb', line 1355 def params @params end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1362 1363 1364 1365 |
# File 'lib/google/apis/memcache_v1/classes.rb', line 1362 def update!(**args) @id = args[:id] if args.key?(:id) @params = args[:params] if args.key?(:params) end |