Class: Google::Apis::MemcacheV1::OperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::MemcacheV1::OperationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/memcache_v1/classes.rb,
lib/google/apis/memcache_v1/representations.rb,
lib/google/apis/memcache_v1/representations.rb
Overview
Represents the metadata of a long-running operation.
Instance Attribute Summary collapse
-
#api_version ⇒ String
Output only.
-
#cancel_requested ⇒ Boolean
(also: #cancel_requested?)
Output only.
-
#create_time ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#status_detail ⇒ String
Output only.
-
#target ⇒ String
Output only.
-
#verb ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperationMetadata
constructor
A new instance of OperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OperationMetadata
Returns a new instance of OperationMetadata.
1542 1543 1544 |
# File 'lib/google/apis/memcache_v1/classes.rb', line 1542 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
Output only. API version used to start the operation.
Corresponds to the JSON property apiVersion
1506 1507 1508 |
# File 'lib/google/apis/memcache_v1/classes.rb', line 1506 def api_version @api_version end |
#cancel_requested ⇒ Boolean Also known as: cancel_requested?
Output only. Identifies whether the user has requested cancellation of the
operation. Operations that have successfully been cancelled have Operation.
error value with a google.rpc.Status.code of 1, corresponding to Code.
CANCELLED.
Corresponds to the JSON property cancelRequested
1514 1515 1516 |
# File 'lib/google/apis/memcache_v1/classes.rb', line 1514 def cancel_requested @cancel_requested end |
#create_time ⇒ String
Output only. Time when the operation was created.
Corresponds to the JSON property createTime
1520 1521 1522 |
# File 'lib/google/apis/memcache_v1/classes.rb', line 1520 def create_time @create_time end |
#end_time ⇒ String
Output only. Time when the operation finished running.
Corresponds to the JSON property endTime
1525 1526 1527 |
# File 'lib/google/apis/memcache_v1/classes.rb', line 1525 def end_time @end_time end |
#status_detail ⇒ String
Output only. Human-readable status of the operation, if any.
Corresponds to the JSON property statusDetail
1530 1531 1532 |
# File 'lib/google/apis/memcache_v1/classes.rb', line 1530 def status_detail @status_detail end |
#target ⇒ String
Output only. Server-defined resource path for the target of the operation.
Corresponds to the JSON property target
1535 1536 1537 |
# File 'lib/google/apis/memcache_v1/classes.rb', line 1535 def target @target end |
#verb ⇒ String
Output only. Name of the verb executed by the operation.
Corresponds to the JSON property verb
1540 1541 1542 |
# File 'lib/google/apis/memcache_v1/classes.rb', line 1540 def verb @verb end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1547 1548 1549 1550 1551 1552 1553 1554 1555 |
# File 'lib/google/apis/memcache_v1/classes.rb', line 1547 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @cancel_requested = args[:cancel_requested] if args.key?(:cancel_requested) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @status_detail = args[:status_detail] if args.key?(:status_detail) @target = args[:target] if args.key?(:target) @verb = args[:verb] if args.key?(:verb) end |