Class: Google::Apis::MemcacheV1::WeeklyMaintenanceWindow

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/memcache_v1/classes.rb,
lib/google/apis/memcache_v1/representations.rb,
lib/google/apis/memcache_v1/representations.rb

Overview

Time window specified for weekly operations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WeeklyMaintenanceWindow

Returns a new instance of WeeklyMaintenanceWindow.



1896
1897
1898
# File 'lib/google/apis/memcache_v1/classes.rb', line 1896

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dayString

Required. Allows to define schedule that runs specified day of the week. Corresponds to the JSON property day

Returns:

  • (String)


1882
1883
1884
# File 'lib/google/apis/memcache_v1/classes.rb', line 1882

def day
  @day
end

#durationString

Required. Duration of the time window. Corresponds to the JSON property duration

Returns:

  • (String)


1887
1888
1889
# File 'lib/google/apis/memcache_v1/classes.rb', line 1887

def duration
  @duration
end

#start_timeGoogle::Apis::MemcacheV1::TimeOfDay

Represents a time of day. The date and time zone are either not significant or are specified elsewhere. An API may choose to allow leap seconds. Related types are google.type.Date and google.protobuf.Timestamp. Corresponds to the JSON property startTime



1894
1895
1896
# File 'lib/google/apis/memcache_v1/classes.rb', line 1894

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1901
1902
1903
1904
1905
# File 'lib/google/apis/memcache_v1/classes.rb', line 1901

def update!(**args)
  @day = args[:day] if args.key?(:day)
  @duration = args[:duration] if args.key?(:duration)
  @start_time = args[:start_time] if args.key?(:start_time)
end