Class: Google::Apis::MemcacheV1::CloudMemorystoreforMemcachedService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::MemcacheV1::CloudMemorystoreforMemcachedService
- Defined in:
- lib/google/apis/memcache_v1/service.rb
Overview
Cloud Memorystore for Memcached API
Google Cloud Memorystore for Memcached API is used for creating and managing Memcached instances in GCP.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://memcache.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#apply_instance_parameters(name, apply_parameters_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MemcacheV1::Operation
ApplyParametersrestarts the set of specified nodes in order to update them to the current set of parameters for the Memcached Instance. -
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MemcacheV1::Empty
Starts asynchronous cancellation on a long-running operation.
-
#create_project_location_instance(parent, instance_object = nil, instance_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MemcacheV1::Operation
Creates a new Instance in a given location.
-
#delete_project_location_instance(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MemcacheV1::Operation
Deletes a single Instance.
-
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MemcacheV1::Empty
Deletes a long-running operation.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MemcacheV1::Location
Gets information about a location.
-
#get_project_location_instance(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MemcacheV1::Instance
Gets details of a single Instance.
-
#get_project_location_instance_tags(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MemcacheV1::GetTagsResponse
Returns tags directly bound to a GCP resource.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MemcacheV1::Operation
Gets the latest state of a long-running operation.
-
#initialize ⇒ CloudMemorystoreforMemcachedService
constructor
A new instance of CloudMemorystoreforMemcachedService.
-
#list_project_location_instances(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MemcacheV1::ListInstancesResponse
Lists Instances in a given location.
-
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MemcacheV1::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MemcacheV1::ListLocationsResponse
Lists information about the supported locations for this service.
-
#patch_project_location_instance(name, instance_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MemcacheV1::Operation
Updates an existing Instance in a given project and location.
-
#reschedule_instance_maintenance(instance, reschedule_maintenance_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MemcacheV1::Operation
Reschedules upcoming maintenance event.
-
#set_instance_tags(name, set_tags_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MemcacheV1::SetTagsResponse
Updates tags directly bound to a GCP resource.
-
#update_instance_parameters(name, update_parameters_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MemcacheV1::Operation
Updates the defined Memcached parameters for an existing instance.
-
#upgrade_project_location_instance(name, google_cloud_memcache_v1_upgrade_instance_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MemcacheV1::Operation
Upgrades the Memcache instance to a newer memcached engine version specified in the request.
Constructor Details
#initialize ⇒ CloudMemorystoreforMemcachedService
Returns a new instance of CloudMemorystoreforMemcachedService.
48 49 50 51 52 53 |
# File 'lib/google/apis/memcache_v1/service.rb', line 48 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-memcache_v1', client_version: Google::Apis::MemcacheV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
41 42 43 |
# File 'lib/google/apis/memcache_v1/service.rb', line 41 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
46 47 48 |
# File 'lib/google/apis/memcache_v1/service.rb', line 46 def quota_user @quota_user end |
Instance Method Details
#apply_instance_parameters(name, apply_parameters_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MemcacheV1::Operation
ApplyParameters restarts the set of specified nodes in order to update them
to the current set of parameters for the Memcached Instance.
159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/google/apis/memcache_v1/service.rb', line 159 def apply_instance_parameters(name, apply_parameters_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:applyParameters', ) command.request_representation = Google::Apis::MemcacheV1::ApplyParametersRequest::Representation command.request_object = apply_parameters_request_object command.response_representation = Google::Apis::MemcacheV1::Operation::Representation command.response_class = Google::Apis::MemcacheV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MemcacheV1::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
566 567 568 569 570 571 572 573 574 575 576 |
# File 'lib/google/apis/memcache_v1/service.rb', line 566 def cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:cancel', ) command.request_representation = Google::Apis::MemcacheV1::CancelOperationRequest::Representation command.request_object = cancel_operation_request_object command.response_representation = Google::Apis::MemcacheV1::Empty::Representation command.response_class = Google::Apis::MemcacheV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_instance(parent, instance_object = nil, instance_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MemcacheV1::Operation
Creates a new Instance in a given location.
201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/google/apis/memcache_v1/service.rb', line 201 def create_project_location_instance(parent, instance_object = nil, instance_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/instances', ) command.request_representation = Google::Apis::MemcacheV1::Instance::Representation command.request_object = instance_object command.response_representation = Google::Apis::MemcacheV1::Operation::Representation command.response_class = Google::Apis::MemcacheV1::Operation command.params['parent'] = parent unless parent.nil? command.query['instanceId'] = instance_id unless instance_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_instance(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MemcacheV1::Operation
Deletes a single Instance.
236 237 238 239 240 241 242 243 244 |
# File 'lib/google/apis/memcache_v1/service.rb', line 236 def delete_project_location_instance(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::MemcacheV1::Operation::Representation command.response_class = Google::Apis::MemcacheV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MemcacheV1::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
601 602 603 604 605 606 607 608 609 |
# File 'lib/google/apis/memcache_v1/service.rb', line 601 def delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::MemcacheV1::Empty::Representation command.response_class = Google::Apis::MemcacheV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MemcacheV1::Location
Gets information about a location.
75 76 77 78 79 80 81 82 83 |
# File 'lib/google/apis/memcache_v1/service.rb', line 75 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::MemcacheV1::Location::Representation command.response_class = Google::Apis::MemcacheV1::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_instance(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MemcacheV1::Instance
Gets details of a single Instance.
268 269 270 271 272 273 274 275 276 |
# File 'lib/google/apis/memcache_v1/service.rb', line 268 def get_project_location_instance(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::MemcacheV1::Instance::Representation command.response_class = Google::Apis::MemcacheV1::Instance command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_instance_tags(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MemcacheV1::GetTagsResponse
Returns tags directly bound to a GCP resource.
298 299 300 301 302 303 304 305 306 |
# File 'lib/google/apis/memcache_v1/service.rb', line 298 def (name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}:getTags', ) command.response_representation = Google::Apis::MemcacheV1::GetTagsResponse::Representation command.response_class = Google::Apis::MemcacheV1::GetTagsResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MemcacheV1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
632 633 634 635 636 637 638 639 640 |
# File 'lib/google/apis/memcache_v1/service.rb', line 632 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::MemcacheV1::Operation::Representation command.response_class = Google::Apis::MemcacheV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_instances(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MemcacheV1::ListInstancesResponse
Lists Instances in a given location.
343 344 345 346 347 348 349 350 351 352 353 354 355 |
# File 'lib/google/apis/memcache_v1/service.rb', line 343 def list_project_location_instances(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/instances', ) command.response_representation = Google::Apis::MemcacheV1::ListInstancesResponse::Representation command.response_class = Google::Apis::MemcacheV1::ListInstancesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MemcacheV1::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
677 678 679 680 681 682 683 684 685 686 687 688 689 |
# File 'lib/google/apis/memcache_v1/service.rb', line 677 def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/operations', ) command.response_representation = Google::Apis::MemcacheV1::ListOperationsResponse::Representation command.response_class = Google::Apis::MemcacheV1::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MemcacheV1::ListLocationsResponse
Lists information about the supported locations for this service. This method
can be called in two ways: * List all public locations: Use the path GET /
v1/locations. * List project-visible locations: Use the path GET /v1/
projects/project_id/locations. This may include public locations as well as
private or other locations specifically visible to the project.
122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/google/apis/memcache_v1/service.rb', line 122 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/locations', ) command.response_representation = Google::Apis::MemcacheV1::ListLocationsResponse::Representation command.response_class = Google::Apis::MemcacheV1::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_instance(name, instance_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MemcacheV1::Operation
Updates an existing Instance in a given project and location.
385 386 387 388 389 390 391 392 393 394 395 396 |
# File 'lib/google/apis/memcache_v1/service.rb', line 385 def patch_project_location_instance(name, instance_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::MemcacheV1::Instance::Representation command.request_object = instance_object command.response_representation = Google::Apis::MemcacheV1::Operation::Representation command.response_class = Google::Apis::MemcacheV1::Operation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#reschedule_instance_maintenance(instance, reschedule_maintenance_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MemcacheV1::Operation
Reschedules upcoming maintenance event.
421 422 423 424 425 426 427 428 429 430 431 |
# File 'lib/google/apis/memcache_v1/service.rb', line 421 def reschedule_instance_maintenance(instance, reschedule_maintenance_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+instance}:rescheduleMaintenance', ) command.request_representation = Google::Apis::MemcacheV1::RescheduleMaintenanceRequest::Representation command.request_object = reschedule_maintenance_request_object command.response_representation = Google::Apis::MemcacheV1::Operation::Representation command.response_class = Google::Apis::MemcacheV1::Operation command.params['instance'] = instance unless instance.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_instance_tags(name, set_tags_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MemcacheV1::SetTagsResponse
Updates tags directly bound to a GCP resource.
454 455 456 457 458 459 460 461 462 463 464 |
# File 'lib/google/apis/memcache_v1/service.rb', line 454 def (name, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:setTags', ) command.request_representation = Google::Apis::MemcacheV1::SetTagsRequest::Representation command.request_object = command.response_representation = Google::Apis::MemcacheV1::SetTagsResponse::Representation command.response_class = Google::Apis::MemcacheV1::SetTagsResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#update_instance_parameters(name, update_parameters_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MemcacheV1::Operation
Updates the defined Memcached parameters for an existing instance. This method
only stages the parameters, it must be followed by ApplyParameters to apply
the parameters to nodes of the Memcached instance.
490 491 492 493 494 495 496 497 498 499 500 |
# File 'lib/google/apis/memcache_v1/service.rb', line 490 def update_instance_parameters(name, update_parameters_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}:updateParameters', ) command.request_representation = Google::Apis::MemcacheV1::UpdateParametersRequest::Representation command.request_object = update_parameters_request_object command.response_representation = Google::Apis::MemcacheV1::Operation::Representation command.response_class = Google::Apis::MemcacheV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#upgrade_project_location_instance(name, google_cloud_memcache_v1_upgrade_instance_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MemcacheV1::Operation
Upgrades the Memcache instance to a newer memcached engine version specified in the request.
526 527 528 529 530 531 532 533 534 535 536 |
# File 'lib/google/apis/memcache_v1/service.rb', line 526 def upgrade_project_location_instance(name, google_cloud_memcache_v1_upgrade_instance_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:upgrade', ) command.request_representation = Google::Apis::MemcacheV1::GoogleCloudMemcacheV1UpgradeInstanceRequest::Representation command.request_object = google_cloud_memcache_v1_upgrade_instance_request_object command.response_representation = Google::Apis::MemcacheV1::Operation::Representation command.response_class = Google::Apis::MemcacheV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |