Class: Google::Apis::MemcacheV1::Instance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/memcache_v1/classes.rb,
lib/google/apis/memcache_v1/representations.rb,
lib/google/apis/memcache_v1/representations.rb

Overview

A Memorystore for Memcached instance

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Instance

Returns a new instance of Instance.



980
981
982
# File 'lib/google/apis/memcache_v1/classes.rb', line 980

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authorized_networkString

The full name of the Google Compute Engine network to which the instance is connected. If left unspecified, the default network will be used. Corresponds to the JSON property authorizedNetwork

Returns:

  • (String)


858
859
860
# File 'lib/google/apis/memcache_v1/classes.rb', line 858

def authorized_network
  @authorized_network
end

#create_timeString

Output only. The time the instance was created. Corresponds to the JSON property createTime

Returns:

  • (String)


863
864
865
# File 'lib/google/apis/memcache_v1/classes.rb', line 863

def create_time
  @create_time
end

#discovery_endpointString

Output only. Endpoint for the Discovery API. Corresponds to the JSON property discoveryEndpoint

Returns:

  • (String)


868
869
870
# File 'lib/google/apis/memcache_v1/classes.rb', line 868

def discovery_endpoint
  @discovery_endpoint
end

#display_nameString

User provided name for the instance, which is only used for display purposes. Cannot be more than 80 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


874
875
876
# File 'lib/google/apis/memcache_v1/classes.rb', line 874

def display_name
  @display_name
end

#instance_messagesArray<Google::Apis::MemcacheV1::InstanceMessage>

List of messages that describe the current state of the Memcached instance. Corresponds to the JSON property instanceMessages



879
880
881
# File 'lib/google/apis/memcache_v1/classes.rb', line 879

def instance_messages
  @instance_messages
end

#labelsHash<String,String>

Resource labels to represent user-provided metadata. Refer to cloud documentation on labels for more details. https://cloud.google.com/compute/ docs/labeling-resources Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


886
887
888
# File 'lib/google/apis/memcache_v1/classes.rb', line 886

def labels
  @labels
end

#maintenance_policyGoogle::Apis::MemcacheV1::GoogleCloudMemcacheV1MaintenancePolicy

Maintenance policy per instance. Corresponds to the JSON property maintenancePolicy



891
892
893
# File 'lib/google/apis/memcache_v1/classes.rb', line 891

def maintenance_policy
  @maintenance_policy
end

#maintenance_scheduleGoogle::Apis::MemcacheV1::MaintenanceSchedule

Upcoming maintenance schedule. Corresponds to the JSON property maintenanceSchedule



896
897
898
# File 'lib/google/apis/memcache_v1/classes.rb', line 896

def maintenance_schedule
  @maintenance_schedule
end

#memcache_full_versionString

Output only. The full version of memcached server running on this instance. System automatically determines the full memcached version for an instance based on the input MemcacheVersion. The full version format will be "memcached- 1.5.16". Corresponds to the JSON property memcacheFullVersion

Returns:

  • (String)


904
905
906
# File 'lib/google/apis/memcache_v1/classes.rb', line 904

def memcache_full_version
  @memcache_full_version
end

#memcache_nodesArray<Google::Apis::MemcacheV1::Node>

Output only. List of Memcached nodes. Refer to Node message for more details. Corresponds to the JSON property memcacheNodes

Returns:



909
910
911
# File 'lib/google/apis/memcache_v1/classes.rb', line 909

def memcache_nodes
  @memcache_nodes
end

#memcache_versionString

The major version of Memcached software. If not provided, latest supported version will be used. Currently the latest supported major version is MEMCACHE_1_5. The minor version will be automatically determined by our system based on the latest supported minor version. Corresponds to the JSON property memcacheVersion

Returns:

  • (String)


917
918
919
# File 'lib/google/apis/memcache_v1/classes.rb', line 917

def memcache_version
  @memcache_version
end

#nameString

Required. Unique name of the resource in this scope including project and location using the form: projects/project_id/locations/location_id/ instances/instance_id`Note: Memcached instances are managed and addressed at the regional level solocation_idhere refers to a Google Cloud region; however, users may choose which zones Memcached nodes should be provisioned in within an instance. Refer to zones field for more details. Corresponds to the JSON propertyname`

Returns:

  • (String)


927
928
929
# File 'lib/google/apis/memcache_v1/classes.rb', line 927

def name
  @name
end

#node_configGoogle::Apis::MemcacheV1::NodeConfig

Configuration for a Memcached Node. Corresponds to the JSON property nodeConfig



932
933
934
# File 'lib/google/apis/memcache_v1/classes.rb', line 932

def node_config
  @node_config
end

#node_countFixnum

Required. Number of nodes in the Memcached instance. Corresponds to the JSON property nodeCount

Returns:

  • (Fixnum)


937
938
939
# File 'lib/google/apis/memcache_v1/classes.rb', line 937

def node_count
  @node_count
end

#parametersGoogle::Apis::MemcacheV1::MemcacheParameters

User defined parameters to apply to the memcached process on each node. Corresponds to the JSON property parameters



942
943
944
# File 'lib/google/apis/memcache_v1/classes.rb', line 942

def parameters
  @parameters
end

#reserved_ip_range_idArray<String>

Optional. Contains the id of allocated IP address ranges associated with the private service access connection for example, "test-default" associated with IP range 10.0.0.0/29. Corresponds to the JSON property reservedIpRangeId

Returns:

  • (Array<String>)


949
950
951
# File 'lib/google/apis/memcache_v1/classes.rb', line 949

def reserved_ip_range_id
  @reserved_ip_range_id
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Optional. Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


954
955
956
# File 'lib/google/apis/memcache_v1/classes.rb', line 954

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Optional. Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


960
961
962
# File 'lib/google/apis/memcache_v1/classes.rb', line 960

def satisfies_pzs
  @satisfies_pzs
end

#stateString

Output only. The state of this Memcached instance. Corresponds to the JSON property state

Returns:

  • (String)


966
967
968
# File 'lib/google/apis/memcache_v1/classes.rb', line 966

def state
  @state
end

#update_timeString

Output only. The time the instance was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


971
972
973
# File 'lib/google/apis/memcache_v1/classes.rb', line 971

def update_time
  @update_time
end

#zonesArray<String>

Zones in which Memcached nodes should be provisioned. Memcached nodes will be equally distributed across these zones. If not provided, the service will by default create nodes in all zones in the region for the instance. Corresponds to the JSON property zones

Returns:

  • (Array<String>)


978
979
980
# File 'lib/google/apis/memcache_v1/classes.rb', line 978

def zones
  @zones
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



985
986
987
988
989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
1005
1006
1007
# File 'lib/google/apis/memcache_v1/classes.rb', line 985

def update!(**args)
  @authorized_network = args[:authorized_network] if args.key?(:authorized_network)
  @create_time = args[:create_time] if args.key?(:create_time)
  @discovery_endpoint = args[:discovery_endpoint] if args.key?(:discovery_endpoint)
  @display_name = args[:display_name] if args.key?(:display_name)
  @instance_messages = args[:instance_messages] if args.key?(:instance_messages)
  @labels = args[:labels] if args.key?(:labels)
  @maintenance_policy = args[:maintenance_policy] if args.key?(:maintenance_policy)
  @maintenance_schedule = args[:maintenance_schedule] if args.key?(:maintenance_schedule)
  @memcache_full_version = args[:memcache_full_version] if args.key?(:memcache_full_version)
  @memcache_nodes = args[:memcache_nodes] if args.key?(:memcache_nodes)
  @memcache_version = args[:memcache_version] if args.key?(:memcache_version)
  @name = args[:name] if args.key?(:name)
  @node_config = args[:node_config] if args.key?(:node_config)
  @node_count = args[:node_count] if args.key?(:node_count)
  @parameters = args[:parameters] if args.key?(:parameters)
  @reserved_ip_range_id = args[:reserved_ip_range_id] if args.key?(:reserved_ip_range_id)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
  @zones = args[:zones] if args.key?(:zones)
end