Class: Google::Apis::MemcacheV1::MemcacheParameters

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/memcache_v1/classes.rb,
lib/google/apis/memcache_v1/representations.rb,
lib/google/apis/memcache_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MemcacheParameters

Returns a new instance of MemcacheParameters.



1336
1337
1338
# File 'lib/google/apis/memcache_v1/classes.rb', line 1336

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. The unique ID associated with this set of parameters. Users can use this id to determine if the parameters associated with the instance differ from the parameters associated with the nodes. A discrepancy between parameter ids can inform users that they may need to take action to apply parameters on nodes. Corresponds to the JSON property id

Returns:

  • (String)


1329
1330
1331
# File 'lib/google/apis/memcache_v1/classes.rb', line 1329

def id
  @id
end

#paramsHash<String,String>

User defined set of parameters to use in the memcached process. Corresponds to the JSON property params

Returns:

  • (Hash<String,String>)


1334
1335
1336
# File 'lib/google/apis/memcache_v1/classes.rb', line 1334

def params
  @params
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1341
1342
1343
1344
# File 'lib/google/apis/memcache_v1/classes.rb', line 1341

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @params = args[:params] if args.key?(:params)
end