Class: Google::Apis::MemcacheV1::Node
- Inherits:
-
Object
- Object
- Google::Apis::MemcacheV1::Node
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/memcache_v1/classes.rb,
lib/google/apis/memcache_v1/representations.rb,
lib/google/apis/memcache_v1/representations.rb
Instance Attribute Summary collapse
-
#host ⇒ String
Output only.
-
#memcache_full_version ⇒ String
Output only.
-
#memcache_version ⇒ String
Output only.
-
#node_id ⇒ String
Output only.
-
#parameters ⇒ Google::Apis::MemcacheV1::MemcacheParameters
User defined parameters currently applied to the node.
-
#port ⇒ Fixnum
Output only.
-
#state ⇒ String
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Node
constructor
A new instance of Node.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Node
Returns a new instance of Node.
1416 1417 1418 |
# File 'lib/google/apis/memcache_v1/classes.rb', line 1416 def initialize(**args) update!(**args) end |
Instance Attribute Details
#host ⇒ String
Output only. Hostname or IP address of the Memcached node used by the clients
to connect to the Memcached server on this node.
Corresponds to the JSON property host
1376 1377 1378 |
# File 'lib/google/apis/memcache_v1/classes.rb', line 1376 def host @host end |
#memcache_full_version ⇒ String
Output only. The full version of memcached server running on this node. e.g. -
memcached-1.5.16
Corresponds to the JSON property memcacheFullVersion
1382 1383 1384 |
# File 'lib/google/apis/memcache_v1/classes.rb', line 1382 def memcache_full_version @memcache_full_version end |
#memcache_version ⇒ String
Output only. Major version of memcached server running on this node, e.g.
MEMCACHE_1_5
Corresponds to the JSON property memcacheVersion
1388 1389 1390 |
# File 'lib/google/apis/memcache_v1/classes.rb', line 1388 def memcache_version @memcache_version end |
#node_id ⇒ String
Output only. Identifier of the Memcached node. The node id does not include
project or location like the Memcached instance name.
Corresponds to the JSON property nodeId
1394 1395 1396 |
# File 'lib/google/apis/memcache_v1/classes.rb', line 1394 def node_id @node_id end |
#parameters ⇒ Google::Apis::MemcacheV1::MemcacheParameters
User defined parameters currently applied to the node.
Corresponds to the JSON property parameters
1399 1400 1401 |
# File 'lib/google/apis/memcache_v1/classes.rb', line 1399 def parameters @parameters end |
#port ⇒ Fixnum
Output only. The port number of the Memcached server on this node.
Corresponds to the JSON property port
1404 1405 1406 |
# File 'lib/google/apis/memcache_v1/classes.rb', line 1404 def port @port end |
#state ⇒ String
Output only. Current state of the Memcached node.
Corresponds to the JSON property state
1409 1410 1411 |
# File 'lib/google/apis/memcache_v1/classes.rb', line 1409 def state @state end |
#zone ⇒ String
Output only. Location (GCP Zone) for the Memcached node.
Corresponds to the JSON property zone
1414 1415 1416 |
# File 'lib/google/apis/memcache_v1/classes.rb', line 1414 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 |
# File 'lib/google/apis/memcache_v1/classes.rb', line 1421 def update!(**args) @host = args[:host] if args.key?(:host) @memcache_full_version = args[:memcache_full_version] if args.key?(:memcache_full_version) @memcache_version = args[:memcache_version] if args.key?(:memcache_version) @node_id = args[:node_id] if args.key?(:node_id) @parameters = args[:parameters] if args.key?(:parameters) @port = args[:port] if args.key?(:port) @state = args[:state] if args.key?(:state) @zone = args[:zone] if args.key?(:zone) end |