Class: Google::Apis::MemcacheV1::Node

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/memcache_v1/classes.rb,
lib/google/apis/memcache_v1/representations.rb,
lib/google/apis/memcache_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Node

Returns a new instance of Node.



1395
1396
1397
# File 'lib/google/apis/memcache_v1/classes.rb', line 1395

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hostString

Output only. Hostname or IP address of the Memcached node used by the clients to connect to the Memcached server on this node. Corresponds to the JSON property host

Returns:

  • (String)


1355
1356
1357
# File 'lib/google/apis/memcache_v1/classes.rb', line 1355

def host
  @host
end

#memcache_full_versionString

Output only. The full version of memcached server running on this node. e.g. - memcached-1.5.16 Corresponds to the JSON property memcacheFullVersion

Returns:

  • (String)


1361
1362
1363
# File 'lib/google/apis/memcache_v1/classes.rb', line 1361

def memcache_full_version
  @memcache_full_version
end

#memcache_versionString

Output only. Major version of memcached server running on this node, e.g. MEMCACHE_1_5 Corresponds to the JSON property memcacheVersion

Returns:

  • (String)


1367
1368
1369
# File 'lib/google/apis/memcache_v1/classes.rb', line 1367

def memcache_version
  @memcache_version
end

#node_idString

Output only. Identifier of the Memcached node. The node id does not include project or location like the Memcached instance name. Corresponds to the JSON property nodeId

Returns:

  • (String)


1373
1374
1375
# File 'lib/google/apis/memcache_v1/classes.rb', line 1373

def node_id
  @node_id
end

#parametersGoogle::Apis::MemcacheV1::MemcacheParameters

User defined parameters currently applied to the node. Corresponds to the JSON property parameters



1378
1379
1380
# File 'lib/google/apis/memcache_v1/classes.rb', line 1378

def parameters
  @parameters
end

#portFixnum

Output only. The port number of the Memcached server on this node. Corresponds to the JSON property port

Returns:

  • (Fixnum)


1383
1384
1385
# File 'lib/google/apis/memcache_v1/classes.rb', line 1383

def port
  @port
end

#stateString

Output only. Current state of the Memcached node. Corresponds to the JSON property state

Returns:

  • (String)


1388
1389
1390
# File 'lib/google/apis/memcache_v1/classes.rb', line 1388

def state
  @state
end

#zoneString

Output only. Location (GCP Zone) for the Memcached node. Corresponds to the JSON property zone

Returns:

  • (String)


1393
1394
1395
# File 'lib/google/apis/memcache_v1/classes.rb', line 1393

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1400
1401
1402
1403
1404
1405
1406
1407
1408
1409
# File 'lib/google/apis/memcache_v1/classes.rb', line 1400

def update!(**args)
  @host = args[:host] if args.key?(:host)
  @memcache_full_version = args[:memcache_full_version] if args.key?(:memcache_full_version)
  @memcache_version = args[:memcache_version] if args.key?(:memcache_version)
  @node_id = args[:node_id] if args.key?(:node_id)
  @parameters = args[:parameters] if args.key?(:parameters)
  @port = args[:port] if args.key?(:port)
  @state = args[:state] if args.key?(:state)
  @zone = args[:zone] if args.key?(:zone)
end