Class: Google::Apis::MemcacheV1::Schedule
- Inherits:
-
Object
- Object
- Google::Apis::MemcacheV1::Schedule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/memcache_v1/classes.rb,
lib/google/apis/memcache_v1/representations.rb,
lib/google/apis/memcache_v1/representations.rb
Overview
Configure the schedule.
Instance Attribute Summary collapse
-
#day ⇒ String
Allows to define schedule that runs specified day of the week.
-
#duration ⇒ String
Output only.
-
#start_time ⇒ Google::Apis::MemcacheV1::TimeOfDay
Represents a time of day.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Schedule
constructor
A new instance of Schedule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Schedule
Returns a new instance of Schedule.
1627 1628 1629 |
# File 'lib/google/apis/memcache_v1/classes.rb', line 1627 def initialize(**args) update!(**args) end |
Instance Attribute Details
#day ⇒ String
Allows to define schedule that runs specified day of the week.
Corresponds to the JSON property day
1613 1614 1615 |
# File 'lib/google/apis/memcache_v1/classes.rb', line 1613 def day @day end |
#duration ⇒ String
Output only. Duration of the time window, set by service producer.
Corresponds to the JSON property duration
1618 1619 1620 |
# File 'lib/google/apis/memcache_v1/classes.rb', line 1618 def duration @duration end |
#start_time ⇒ Google::Apis::MemcacheV1::TimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property startTime
1625 1626 1627 |
# File 'lib/google/apis/memcache_v1/classes.rb', line 1625 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1632 1633 1634 1635 1636 |
# File 'lib/google/apis/memcache_v1/classes.rb', line 1632 def update!(**args) @day = args[:day] if args.key?(:day) @duration = args[:duration] if args.key?(:duration) @start_time = args[:start_time] if args.key?(:start_time) end |