Class: Google::Apis::MemcacheV1::Schedule
- Inherits:
-
Object
- Object
- Google::Apis::MemcacheV1::Schedule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/memcache_v1/classes.rb,
lib/google/apis/memcache_v1/representations.rb,
lib/google/apis/memcache_v1/representations.rb
Overview
Configure the schedule.
Instance Attribute Summary collapse
-
#day ⇒ String
Allows to define schedule that runs specified day of the week.
-
#duration ⇒ String
Output only.
-
#start_time ⇒ Google::Apis::MemcacheV1::TimeOfDay
Represents a time of day.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Schedule
constructor
A new instance of Schedule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Schedule
Returns a new instance of Schedule.
1606 1607 1608 |
# File 'lib/google/apis/memcache_v1/classes.rb', line 1606 def initialize(**args) update!(**args) end |
Instance Attribute Details
#day ⇒ String
Allows to define schedule that runs specified day of the week.
Corresponds to the JSON property day
1592 1593 1594 |
# File 'lib/google/apis/memcache_v1/classes.rb', line 1592 def day @day end |
#duration ⇒ String
Output only. Duration of the time window, set by service producer.
Corresponds to the JSON property duration
1597 1598 1599 |
# File 'lib/google/apis/memcache_v1/classes.rb', line 1597 def duration @duration end |
#start_time ⇒ Google::Apis::MemcacheV1::TimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property startTime
1604 1605 1606 |
# File 'lib/google/apis/memcache_v1/classes.rb', line 1604 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1611 1612 1613 1614 1615 |
# File 'lib/google/apis/memcache_v1/classes.rb', line 1611 def update!(**args) @day = args[:day] if args.key?(:day) @duration = args[:duration] if args.key?(:duration) @start_time = args[:start_time] if args.key?(:start_time) end |